# Rapid Router

[![Workflow Status](https://github.com/ocadotechnology/rapid-router/actions/workflows/ci.yml/badge.svg)](https://github.com/ocadotechnology/rapid-router/actions/workflows/ci.yml)
[![Coverage Status](https://codecov.io/gh/ocadotechnology/rapid-router/branch/master/graph/badge.svg)](https://codecov.io/gh/ocadotechnology/rapid-router)

[Code for Life](https://www.codeforlife.education/) has been developed by Ocado Technology as a **free, open-source** project to inspire the next generation of computer scientists and to help teachers deliver the computing curriculum.

**Rapid Router** is a [Code for Life](https://www.codeforlife.education/) project, primarily aimed at teaching primary school students programming concepts through a vehicle routing game (older students welcome). It starts with [Blockly](https://developers.google.com/blockly) and transitions to Python.

This repository hosts the source code of the **Rapid Router game**.

We are open to contributors from anywhere around the world. Please read ahead if you'd like to get involved.

## To get started

- [Developer Guide](https://docs.codeforlife.education/developer-guide)

- [Good First Issues](https://github.com/ocadotechnology/rapid-router/contribute)

- [How to set up your work environment](https://docs.codeforlife.education/git/common-setup)

- [Testing](https://docs.codeforlife.education/git/testing)
